PowerCmd

Trait PowerCmd 

pub trait PowerCmd {
    // Required methods
    fn start(&self) -> VmResult<()>;
    fn stop<D: Into<Option<Duration>>>(&self, timeout: D) -> VmResult<()>;
    fn hard_stop(&self) -> VmResult<()>;
    fn suspend(&self) -> VmResult<()>;
    fn resume(&self) -> VmResult<()>;
    fn is_running(&self) -> VmResult<bool>;
    fn reboot<D: Into<Option<Duration>>>(&self, timeout: D) -> VmResult<()>;
    fn hard_reboot(&self) -> VmResult<()>;
    fn pause(&self) -> VmResult<()>;
    fn unpause(&self) -> VmResult<()>;
}
A trait for managing power state of a VM.

Required Methods

fn start(&self) -> VmResult<()>

Starts the VM and waits for the VM to start.

fn stop<D: Into<Option<Duration>>>(&self, timeout: D) -> VmResult<()>

Stops the VM softly and waits for the VM to stop.

This function usually only sends a ACPI shutdown signal, so there is no guarantee that calling this function will shut down the VM.

fn hard_stop(&self) -> VmResult<()>

Stops the VM hardly and waits for the VM to stop.

fn suspend(&self) -> VmResult<()>

Suspends the VM and waits for the VM to suspend.

fn resume(&self) -> VmResult<()>

Resumes the suspended VM.

fn is_running(&self) -> VmResult<bool>

Returns true if the VM is running.

fn reboot<D: Into<Option<Duration>>>(&self, timeout: D) -> VmResult<()>

Reboots the VM softly and waits for the VM to start.

fn hard_reboot(&self) -> VmResult<()>

Reboots the VM hardly and waits for the VM to start.

fn pause(&self) -> VmResult<()>

Pauses the VM and waits for the VM to pause.

fn unpause(&self) -> VmResult<()>

Unpauses the VM and waits for the VM to unpause.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors